package com.muyu.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;

/**
 * @Author：yang
 * @Package：com.muyu.domain
 * @Project：cloud-server-8
 * @name：CarInformation
 * @Date：2024/9/22 22:18
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Tag(name = "企业车辆管理实体类")
@TableName(value = "car_information",autoResultMap = true)
public class CarInformation {

    /**
     * 车辆ID
     */
    @TableId(value = "car_information_id",type = IdType.AUTO)
    private Integer carInformationId;
    /**
     * 车辆唯一VIN
     */
//    @TableName(value = "car_information_VIN")
            @TableField(value = "car_information_VIN")
    private String carInformationVin;
    /**
     * 车牌号
     */
    private String carInformationLicensePlate;
    /**
     * 车辆颜色
     */
    private String carInformationColor;
    /**
     * 车辆驾驶员
     */
    private String carInformationDriver;
    /**
     * 车辆电子围栏外键ID
     */
    private String carInformationFence;
    /**
     * 车检到期日期
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(locale="zh", timezone="GMT+8", pattern="yyyy-MM-dd")
    private Date carInformationExamineEnddata;
    /**
     * 车辆类型外键ID
     */
    private Integer carInformationType;
    /**
     * 车辆品牌外键ID
     */
    private Integer carInformationBrand;
    /**
     * 是否重点车辆 (0否默认 1是 )
     */
    private Integer carInformationFocus;

    /**
     * 车辆电机厂商
     */
    private String carInformationMotorManufacturer;

    /**
     * 车辆电机型号
     */
    private String carInformationMotorModel;

    /**
     * 车辆电池厂商
     */
    private String carInformationBatteryManufacturer;

    /**
     * 车辆电池型号
     */
    private String carInformationBatteryModel;

    /**
     * 启用状态(1.在线 2.离线 3.已断开 4.待连接 5.维修中)
     */
    private Integer carInformationState;

    public static CarInformation carInformationBuilder(CarInformation carInformation) {
        return CarInformation.builder()
                .carInformationId(carInformation.getCarInformationId())
                .carInformationLicensePlate(carInformation.getCarInformationLicensePlate())
                .build();
    }
}
